==> testsuite-1.0.8-beta1.tar.gz: testsuite/src/Controller/TestSuiteController.php <==
<?php

namespace Drupal\testsuite\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\testsuite\LoadResourceService;
use Drupal\testsuite\TestMenuService;
use Drupal\testsuite\ShellExecService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Returns responses for test reports routes.
 */
class TestSuiteController extends ControllerBase {

  /**
   * @var \Drupal\testsuite\LoadResourceService
   */
  protected $_loadResourceService;

  /**
   * @var \Drupal\testsuite\TestMenuService
   */
  protected $_testMenuService;

  /**
   * @var \Drupal\testsuite\ShellExecService
   */
  protected $_shellExecService;

  /**
   * @var array The array of files to create Resource with.
   */
  protected $_loadedFiles = [];

  /**
   * Constructs a new TMGMTLocalController.
   *
   * @param \Drupal\testsuite\LoadResourceService $loadResourceService
   * @param \Drupal\testsuite\TestMenuService $testMenuService
   * @param \Drupal\testsuite\ShellExecService $shellExecService
   */
  public function __construct(
    LoadResourceService $loadResourceService,
    TestMenuService $testMenuService,
    ShellExecService $shellExecService
  ) {
    $this->_testMenuService = $testMenuService;
    $this->_loadResourceService = $loadResourceService;
    $this->_shellExecService = $shellExecService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('testsuite.load_resource.service'),
      $container->get('testsuite.test_menu.service'),
      $container->get('testsuite.shell_exec.service')
    );
  }

  /**
   * Provides a single block from the administration menu as a page.
   */
  public function customReport(Request $request) {
    $output['test_menu'] = $this->_testMenuService->buildTestsMenu();
    foreach($this->_loadResourceService->getResource('report', 'contrib', 'testsuite', 'all', 'all') as $file) {
      $className = basename($file, '.php');
      $class = '\Drupal\testsuite\Tests\\'.$className;
      require_once $file;
      if(class_exists($class)) {
        $obj = new $class;
        $this->_loadedFiles[$className] = array(
          'file' => $file,
          'moduleName' => $obj->getModuleName(),
          'name' => $obj->getName(),
          'description' => $obj->getDescription(),
          'class' => '\Drupal\testsuite\Tests\\'.$className,
        );
      }
    }

    $header = array(
      $this->t('Name'),
      $this->t('Results')
    );

    $result = array();
    foreach($this->_loadedFiles as $className => $values) {
      $results = $request->getSession()->get($className);
      if($results) {
        $result[] = array(
          'name' => $values['name'],
          'results' => $results
        );
      }
    }

    $rows = array();

    foreach ($result as $dblog) {
      // var_dump($dblog);
      $rows[] = array(
        $dblog['name'],
        $dblog['results']
      );
    }

    if (empty($rows)) {
      $rows[] = array(array(
        'Type' => $this->t('No report messages available.'),
        'colspan' => 3,
      ));
    }

    $output['table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#attributes' => [
        'class' => [
          'test-suite-table'
        ]
      ]
    ];

    return $output;
  }

  public function phpUnitReport(Request $request) {
    $output['top_menu'] = $this->_testMenuService->buildTestsMenu();
    $sessionArea = $request->getSession()->get('area');
    $sessionModule = $request->getSession()->get('module');
    $sessionDirectory = $request->getSession()->get('directory');
    // \Drupal::messenger()->addStatus('Area: '.$sessionArea);
    // \Drupal::messenger()->addStatus('Module: '.$sessionModule);
    $this->_loadedFiles = $this->_loadResourceService->getResource('report', 'phpunit', $sessionArea, $sessionModule, $sessionDirectory);
    // \Drupal::messenger()->addStatus('Count: '.count($this->_loadedFiles));

    $classArray = array();
    $errorArray = array();

    foreach($this->_loadedFiles as $module => $statement) {
      $results = $this->_shellExecService->getData($statement);
      $classArray = $this->_shellExecService->getReportMore($module, $results);
      if($this->_shellExecService->ifErrors($results))
        $errorArray = $this->_shellExecService->getErrorArray($module, $results);

      $result[] = array(
        'module' => $module,
        'name' => $statement,
        'results' => \Drupal\Core\Render\Markup::create($this->_shellExecService->GetReportHeading($results))
      );
    }

    $table = '<table class="test-suite-table responsive-enabled">';
    $table .= '<thead><tr><th>Name</th><th>Results</th><th>Actions</th></tr></thead>';

    for ($i = 0; $i<count($result); $i++) {
      $table .= '<tr class="test-suite-test-report-rows">';
      $table .= '<td>'.$result[$i]['name'].'</td>';
      $table .= '<td width="50%">'.$result[$i]['results'].'</td>';
      $table .= '<td><a href="#" class="button button--primary test-suite-table-row-show-button">Show Report</a></td>';
      $table .= '</tr>';
      if(isset($classArray[$result[$i]['module']])) {
        $table .= '<tr class="test-suite-test-report-table-rows">';
        $table .= '<td class="test-suite-test-report-table-columns" colspan="3">';
          $table .= '<table class="test-suite-table responsive-enabled">';
          $table .= '<thead><tr><th>Class Name</th><th>Tests Ran</th><th>Results</th></tr></thead>';
          for ($j = 0; $j<count($classArray[$result[$i]['module']]); $j++) {

            $table .= '<tr>';
            $table .= '<td>'.$classArray[$result[$i]['module']][$j]['class'].'</td>';
            $table .= '<td>'.$classArray[$result[$i]['module']][$j]['count'].'</td>';
            $table .= '<td>Tested.</td>';
            $table .= '</tr>';

          }
          if(isset($errorArray[$result[$i]['module']])) {
            for ($j = 0; $j<count($errorArray[$result[$i]['module']]); $j++) {

              $table .= '<tr>';
              $table .= '<td colspan="3">'.$errorArray[$result[$i]['module']][$j].'</td>';
              $table .= '</tr>';

            }
          }
          $table .= '</table>';
        $table .= '</td></tr>';
      }
    }

    if(empty($result)) {
      $table .= '<tr><td colspan="3">There are no results yet.</td></tr>';
    }
    $table .= '</table>';

    $output['table'] = array(
      '#type' => 'markup',
      '#markup' => $table
    );
    return $output;
  }

  public function phpUnitFileReport($area, $module, $directory, $file = null) {
    $output['top_menu'] = $this->_testMenuService->buildTestsMenu();
    // \Drupal::messenger()->addStatus('Area: '.$sessionArea);
    // \Drupal::messenger()->addStatus('Module: '.$sessionModule);
    if($file == null) {
      $statement = $this->_loadResourceService->getStatement($area, $module, $directory);
    } else {
      $statement = $this->_loadResourceService->getFileStatement($area, $module, $directory, $file);
    }

    // dd($statement);

    $classArray = array();
    $errorArray = array();

    $results = $this->_shellExecService->getData($statement);
    $classArray = $this->_shellExecService->getReportMore($module, $results);
    if($this->_shellExecService->ifErrors($results))
      $errorArray = $this->_shellExecService->getErrorArray($module, $results);

    $result[] = array(
      'module' => $module,
      'name' => $statement,
      'results' => \Drupal\Core\Render\Markup::create($this->_shellExecService->GetReportHeading($results))
    );

    $table = '<table class="test-suite-table responsive-enabled">';
    $table .= '<thead><tr><th>Name</th><th>Results</th><th>Actions</th></tr></thead>';

    for ($i = 0; $i<count($result); $i++) {
      $table .= '<tr class="test-suite-test-report-rows">';
      $table .= '<td>'.$result[$i]['name'].'</td>';
      $table .= '<td width="50%">'.$result[$i]['results'].'</td>';
      $table .= '<td><a href="#" class="button button--primary test-suite-table-row-show-button">Show Report</a></td>';
      $table .= '</tr>';
      if(isset($classArray[$result[$i]['module']])) {
        $table .= '<tr class="test-suite-test-report-table-rows">';
        $table .= '<td class="test-suite-test-report-table-columns" colspan="3">';
          $table .= '<table class="test-suite-table responsive-enabled">';
          $table .= '<thead><tr><th>Class Name</th><th>Tests Ran</th><th>Results</th></tr></thead>';
          for ($j = 0; $j<count($classArray[$result[$i]['module']]); $j++) {

            $table .= '<tr>';
            $table .= '<td>'.$classArray[$result[$i]['module']][$j]['class'].'</td>';
            $table .= '<td>'.$classArray[$result[$i]['module']][$j]['count'].'</td>';
            $table .= '<td>Tested.</td>';
            $table .= '</tr>';

          }
          if(isset($errorArray[$result[$i]['module']])) {
            for ($j = 0; $j<count($errorArray[$result[$i]['module']]); $j++) {

              $table .= '<tr>';
              $table .= '<td colspan="3">'.$errorArray[$result[$i]['module']][$j].'</td>';
              $table .= '</tr>';

            }
          }
          $table .= '</table>';
        $table .= '</td></tr>';
      }
    }

    if(empty($result)) {
      $table .= '<tr><td colspan="3">There are no results yet.</td></tr>';
    }
    $table .= '</table>';

    $output['table'] = array(
      '#type' => 'markup',
      '#markup' => $table
    );
    return $output;
  }

}

==> testsuite-1.0.9-beta1.tar.gz: testsuite/src/Controller/TestSuiteController.php <==
<?php

namespace Drupal\testsuite\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\testsuite\LoadResourceService;
use Drupal\testsuite\TestMenuService;
use Drupal\testsuite\ShellExecService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Returns responses for test reports routes.
 */
class TestSuiteController extends ControllerBase {

  /**
   * @var \Drupal\testsuite\LoadResourceService
   */
  protected $_loadResourceService;

  /**
   * @var \Drupal\testsuite\TestMenuService
   */
  protected $_testMenuService;

  /**
   * @var \Drupal\testsuite\ShellExecService
   */
  protected $_shellExecService;

  /**
   * @var array The array of files to create Resource with.
   */
  protected $_loadedFiles = [];

  /**
   * Constructs a new TMGMTLocalController.
   *
   * @param \Drupal\testsuite\LoadResourceService $loadResourceService
   * @param \Drupal\testsuite\TestMenuService $testMenuService
   * @param \Drupal\testsuite\ShellExecService $shellExecService
   */
  public function __construct(
    LoadResourceService $loadResourceService,
    TestMenuService $testMenuService,
    ShellExecService $shellExecService
  ) {
    $this->_testMenuService = $testMenuService;
    $this->_loadResourceService = $loadResourceService;
    $this->_shellExecService = $shellExecService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('testsuite.load_resource.service'),
      $container->get('testsuite.test_menu.service'),
      $container->get('testsuite.shell_exec.service')
    );
  }

  /**
   * Provides a single block from the administration menu as a page.
   */
  public function customReport(Request $request) {
    $output['test_menu'] = $this->_testMenuService->buildTestsMenu();
    foreach($this->_loadResourceService->getResource('report', 'custom', 'testsuite', 'all', 'all') as $file) {
      $className = basename($file, '.php');
      $class = '\Drupal\testsuite\Tests\\'.$className;
      require_once $file;
      if(class_exists($class)) {
        $obj = new $class;
        $this->_loadedFiles[$className] = array(
          'file' => $file,
          'moduleName' => $obj->getModuleName(),
          'name' => $obj->getName(),
          'description' => $obj->getDescription(),
          'class' => '\Drupal\testsuite\Tests\\'.$className,
        );
      }
    }

    $header = array(
      $this->t('Name'),
      $this->t('Results')
    );

    $result = array();
    foreach($this->_loadedFiles as $className => $values) {
      $results = $request->getSession()->get($className);
      if($results) {
        $result[] = array(
          'name' => $values['name'],
          'results' => $results
        );
      }
    }

    $rows = array();

    foreach ($result as $dblog) {
      // var_dump($dblog);
      $rows[] = array(
        $dblog['name'],
        $dblog['results']
      );
    }

    if (empty($rows)) {
      $rows[] = array(array(
        'Type' => $this->t('No report messages available.'),
        'colspan' => 3,
      ));
    }

    $output['table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#attributes' => [
        'class' => [
          'test-suite-table'
        ]
      ]
    ];

    return $output;
  }

  public function phpUnitReport(Request $request) {
    $output['top_menu'] = $this->_testMenuService->buildTestsMenu();
    $sessionArea = $request->getSession()->get('area');
    $sessionModule = $request->getSession()->get('module');
    $sessionDirectory = $request->getSession()->get('directory');
    // \Drupal::messenger()->addStatus('Area: '.$sessionArea);
    // \Drupal::messenger()->addStatus('Module: '.$sessionModule);
    $this->_loadedFiles = $this->_loadResourceService->getResource('report', 'phpunit', $sessionArea, $sessionModule, $sessionDirectory);
    // \Drupal::messenger()->addStatus('Count: '.count($this->_loadedFiles));

    $classArray = array();
    $errorArray = array();

    foreach($this->_loadedFiles as $module => $statement) {
      $results = $this->_shellExecService->getData($statement);
      $classArray = $this->_shellExecService->getReportMore($module, $results);
      if($this->_shellExecService->ifErrors($results))
        $errorArray = $this->_shellExecService->getErrorArray($module, $results);

      $result[] = array(
        'module' => $module,
        'name' => $statement,
        'results' => \Drupal\Core\Render\Markup::create($this->_shellExecService->GetReportHeading($results))
      );
    }

    $table = '<table class="test-suite-table responsive-enabled">';
    $table .= '<thead><tr><th>Name</th><th>Results</th><th>Actions</th></tr></thead>';

    for ($i = 0; $i<count($result); $i++) {
      $table .= '<tr class="test-suite-test-report-rows">';
      $table .= '<td>'.$result[$i]['name'].'</td>';
      $table .= '<td width="50%">'.$result[$i]['results'].'</td>';
      $table .= '<td><a href="#" class="button button--primary test-suite-table-row-show-button">Show Report</a></td>';
      $table .= '</tr>';
      if(isset($classArray[$result[$i]['module']])) {
        $table .= '<tr class="test-suite-test-report-table-rows">';
        $table .= '<td class="test-suite-test-report-table-columns" colspan="3">';
          $table .= '<table class="test-suite-table responsive-enabled">';
          $table .= '<thead><tr><th>Class Name</th><th>Tests Ran</th><th>Results</th></tr></thead>';
          for ($j = 0; $j<count($classArray[$result[$i]['module']]); $j++) {

            $table .= '<tr>';
            $table .= '<td>'.$classArray[$result[$i]['module']][$j]['class'].'</td>';
            $table .= '<td>'.$classArray[$result[$i]['module']][$j]['count'].'</td>';
            $table .= '<td>Tested.</td>';
            $table .= '</tr>';

          }
          if(isset($errorArray[$result[$i]['module']])) {
            for ($j = 0; $j<count($errorArray[$result[$i]['module']]); $j++) {

              $table .= '<tr>';
              $table .= '<td colspan="3">'.$errorArray[$result[$i]['module']][$j].'</td>';
              $table .= '</tr>';

            }
          }
          $table .= '</table>';
        $table .= '</td></tr>';
      }
    }

    if(empty($result)) {
      $table .= '<tr><td colspan="3">There are no results yet.</td></tr>';
    }
    $table .= '</table>';

    $output['table'] = array(
      '#type' => 'markup',
      '#markup' => $table
    );
    return $output;
  }

  public function phpUnitFileReport($area, $module, $directory, $file = null) {
    $output['top_menu'] = $this->_testMenuService->buildTestsMenu();
    // \Drupal::messenger()->addStatus('Area: '.$sessionArea);
    // \Drupal::messenger()->addStatus('Module: '.$sessionModule);
    if($file == null) {
      $statement = $this->_loadResourceService->getStatement($area, $module, $directory);
    } else {
      $statement = $this->_loadResourceService->getFileStatement($area, $module, $directory, $file);
    }

    // dd($statement);

    $classArray = array();
    $errorArray = array();

    $results = $this->_shellExecService->getData($statement);
    $classArray = $this->_shellExecService->getReportMore($module, $results);
    if($this->_shellExecService->ifErrors($results))
      $errorArray = $this->_shellExecService->getErrorArray($module, $results);

    $result[] = array(
      'module' => $module,
      'name' => $statement,
      'results' => \Drupal\Core\Render\Markup::create($this->_shellExecService->GetReportHeading($results))
    );

    $table = '<table class="test-suite-table responsive-enabled">';
    $table .= '<thead><tr><th>Name</th><th>Results</th><th>Actions</th></tr></thead>';

    for ($i = 0; $i<count($result); $i++) {
      $table .= '<tr class="test-suite-test-report-rows">';
      $table .= '<td>'.$result[$i]['name'].'</td>';
      $table .= '<td width="50%">'.$result[$i]['results'].'</td>';
      $table .= '<td><a href="#" class="button button--primary test-suite-table-row-show-button">Show Report</a></td>';
      $table .= '</tr>';
      if(isset($classArray[$result[$i]['module']])) {
        $table .= '<tr class="test-suite-test-report-table-rows">';
        $table .= '<td class="test-suite-test-report-table-columns" colspan="3">';
          $table .= '<table class="test-suite-table responsive-enabled">';
          $table .= '<thead><tr><th>Class Name</th><th>Tests Ran</th><th>Results</th></tr></thead>';
          for ($j = 0; $j<count($classArray[$result[$i]['module']]); $j++) {

            $table .= '<tr>';
            $table .= '<td>'.$classArray[$result[$i]['module']][$j]['class'].'</td>';
            $table .= '<td>'.$classArray[$result[$i]['module']][$j]['count'].'</td>';
            $table .= '<td>Tested.</td>';
            $table .= '</tr>';

          }
          if(isset($errorArray[$result[$i]['module']])) {
            for ($j = 0; $j<count($errorArray[$result[$i]['module']]); $j++) {

              $table .= '<tr>';
              $table .= '<td colspan="3">'.$errorArray[$result[$i]['module']][$j].'</td>';
              $table .= '</tr>';

            }
          }
          $table .= '</table>';
        $table .= '</td></tr>';
      }
    }

    if(empty($result)) {
      $table .= '<tr><td colspan="3">There are no results yet.</td></tr>';
    }
    $table .= '</table>';

    $output['table'] = array(
      '#type' => 'markup',
      '#markup' => $table
    );
    return $output;
  }

}
